@@ -3,10 +3,8 @@ package linodego
 import (
 	"context"
 	"encoding/json"
-	"fmt"
 	"time"
 
-	"github.com/go-resty/resty/v2"
 	"github.com/linode/linodego/internal/parseabletime"
 )
 
@@ -19,33 +17,13 @@ type Login struct {
 	Status     string     `json:"status"`
 }
 
-type LoginsPagedResponse struct {
-	*PageOptions
-	Data []Login `json:"data"`
-}
-
-func (LoginsPagedResponse) endpoint(_ ...any) string {
-	return "account/logins"
-}
-
-func (resp *LoginsPagedResponse) castResult(r *resty.Request, e string) (int, int, error) {
-	res, err := coupleAPIErrors(r.SetResult(LoginsPagedResponse{}).Get(e))
-	if err != nil {
-		return 0, 0, err
-	}
-	castedRes := res.Result().(*LoginsPagedResponse)
-	resp.Data = append(resp.Data, castedRes.Data...)
-	return castedRes.Pages, castedRes.Results, nil
-}
-
 func (c *Client) ListLogins(ctx context.Context, opts *ListOptions) ([]Login, error) {
-	response := LoginsPagedResponse{}
-	err := c.listHelper(ctx, &response, opts)
+	response, err := getPaginatedResults[Login](ctx, c, "account/logins", opts)
 	if err != nil {
 		return nil, err
 	}
 
-	return response.Data, nil
+	return response, nil
 }
 
 // UnmarshalJSON implements the json.Unmarshaler interface
@@ -69,12 +47,12 @@ func (i *Login) UnmarshalJSON(b []byte) error {
 }
 
 func (c *Client) GetLogin(ctx context.Context, loginID int) (*Login, error) {
-	req := c.R(ctx).SetResult(&Login{})
-	e := fmt.Sprintf("account/logins/%d", loginID)
-	r, err := coupleAPIErrors(req.Get(e))
+	e := formatAPIPath("account/logins/%d", loginID)
+
+	response, err := doGETRequest[Login](ctx, c, e)
 	if err != nil {
 		return nil, err
 	}
 
-	return r.Result().(*Login), nil
+	return response, nil
 }
