@@ -2,7 +2,6 @@ package linodego
 
 import (
 	"context"
-	"fmt"
 )
 
 // NodeBalancerStats represents a nodebalancer stats object
@@ -25,12 +24,11 @@ type StatsTraffic struct {
 
 // GetNodeBalancerStats gets the template with the provided ID
 func (c *Client) GetNodeBalancerStats(ctx context.Context, nodebalancerID int) (*NodeBalancerStats, error) {
-	e := fmt.Sprintf("nodebalancers/%d/stats", nodebalancerID)
-	req := c.R(ctx).SetResult(&NodeBalancerStats{})
-	r, err := coupleAPIErrors(req.Get(e))
+	e := formatAPIPath("nodebalancers/%d/stats", nodebalancerID)
+	response, err := doGETRequest[NodeBalancerStats](ctx, c, e)
 	if err != nil {
 		return nil, err
 	}
 
-	return r.Result().(*NodeBalancerStats), nil
+	return response, nil
 }
