@@ -2,7 +2,6 @@ package linodego
 
 import (
 	"context"
-	"encoding/json"
 )
 
 // SendPhoneNumberVerificationCodeOptions fields are those accepted by SendPhoneNumberVerificationCode
@@ -18,31 +17,23 @@ type VerifyPhoneNumberOptions struct {
 
 // SendPhoneNumberVerificationCode sends a one-time verification code via SMS message to the submitted phone number.
 func (c *Client) SendPhoneNumberVerificationCode(ctx context.Context, opts SendPhoneNumberVerificationCodeOptions) error {
-	body, err := json.Marshal(opts)
-	if err != nil {
-		return err
-	}
-
 	e := "profile/phone-number"
-	_, err = coupleAPIErrors(c.R(ctx).SetBody(string(body)).Post(e))
+	_, err := doPOSTRequest[any](ctx, c, e, opts)
+
 	return err
 }
 
 // DeletePhoneNumber deletes the verified phone number for the User making this request.
 func (c *Client) DeletePhoneNumber(ctx context.Context) error {
 	e := "profile/phone-number"
-	_, err := coupleAPIErrors(c.R(ctx).Delete(e))
+	err := doDELETERequest(ctx, c, e)
 	return err
 }
 
 // VerifyPhoneNumber verifies a phone number by confirming the one-time code received via SMS message after accessing the Phone Verification Code Send command.
 func (c *Client) VerifyPhoneNumber(ctx context.Context, opts VerifyPhoneNumberOptions) error {
-	body, err := json.Marshal(opts)
-	if err != nil {
-		return err
-	}
-
 	e := "profile/phone-number/verify"
-	_, err = coupleAPIErrors(c.R(ctx).SetBody(string(body)).Post(e))
+	_, err := doPOSTRequest[any](ctx, c, e, opts)
+
 	return err
 }
