@@ -2,7 +2,6 @@ package linodego
 
 import (
 	"context"
-	"encoding/json"
 )
 
 type SecurityQuestion struct {
@@ -27,23 +26,18 @@ type SecurityQuestionsAnswerOptions struct {
 // SecurityQuestionsList returns a collection of security questions and their responses, if any, for your User Profile.
 func (c *Client) SecurityQuestionsList(ctx context.Context) (*SecurityQuestionsListResponse, error) {
 	e := "profile/security-questions"
-	req := c.R(ctx).SetResult(&SecurityQuestionsListResponse{})
-	r, err := coupleAPIErrors(req.Get(e))
+	response, err := doGETRequest[SecurityQuestionsListResponse](ctx, c, e)
 	if err != nil {
 		return nil, err
 	}
-	return r.Result().(*SecurityQuestionsListResponse), nil
+
+	return response, nil
 }
 
 // SecurityQuestionsAnswer adds security question responses for your User.
 func (c *Client) SecurityQuestionsAnswer(ctx context.Context, opts SecurityQuestionsAnswerOptions) error {
-	body, err := json.Marshal(opts)
-	if err != nil {
-		return err
-	}
-
 	e := "profile/security-questions"
-	req := c.R(ctx).SetBody(string(body))
-	_, err = coupleAPIErrors(req.Post(e))
+
+	_, err := doPOSTRequest[any](ctx, c, e, opts)
 	return err
 }
