@@ -10,31 +10,39 @@ import (
 // Defined as strings rather than a custom type to avoid breaking change.
 // Can be changed in the potential v2 version.
 const (
-	CapabilityLinodes                string = "Linodes"
-	CapabilityNodeBalancers          string = "NodeBalancers"
-	CapabilityBlockStorage           string = "Block Storage"
-	CapabilityObjectStorage          string = "Object Storage"
-	CapabilityObjectStorageRegions   string = "Object Storage Access Key Regions"
-	CapabilityLKE                    string = "Kubernetes"
-	CapabilityLkeHaControlPlanes     string = "LKE HA Control Planes"
-	CapabilityCloudFirewall          string = "Cloud Firewall"
-	CapabilityGPU                    string = "GPU Linodes"
-	CapabilityVlans                  string = "Vlans"
-	CapabilityVPCs                   string = "VPCs"
-	CapabilityVPCsExtra              string = "VPCs Extra"
-	CapabilityMachineImages          string = "Machine Images"
-	CapabilityBareMetal              string = "Bare Metal"
-	CapabilityDBAAS                  string = "Managed Databases"
-	CapabilityBlockStorageMigrations string = "Block Storage Migrations"
-	CapabilityMetadata               string = "Metadata"
-	CapabilityPremiumPlans           string = "Premium Plans"
-	CapabilityEdgePlans              string = "Edge Plans"
-	CapabilityLKEControlPlaneACL     string = "LKE Network Access Control List (IP ACL)"
-	CapabilityACLB                   string = "Akamai Cloud Load Balancer"
-	CapabilitySupportTicketSeverity  string = "Support Ticket Severity"
-	CapabilityBackups                string = "Backups"
-	CapabilityPlacementGroup         string = "Placement Group"
-	CapabilityDiskEncryption         string = "Disk Encryption"
+	CapabilityACLB                          string = "Akamai Cloud Load Balancer"
+	CapabilityBackups                       string = "Backups"
+	CapabilityBareMetal                     string = "Bare Metal"
+	CapabilityBlockStorage                  string = "Block Storage"
+	CapabilityBlockStorageEncryption        string = "Block Storage Encryption"
+	CapabilityBlockStorageMigrations        string = "Block Storage Migrations"
+	CapabilityCloudFirewall                 string = "Cloud Firewall"
+	CapabilityDBAAS                         string = "Managed Databases"
+	CapabilityDiskEncryption                string = "Disk Encryption"
+	CapabilityEdgePlans                     string = "Edge Plans"
+	CapabilityGPU                           string = "GPU Linodes"
+	CapabilityKubernetesEnterprise          string = "Kubernetes Enterprise"
+	CapabilityLKE                           string = "Kubernetes"
+	CapabilityLKEControlPlaneACL            string = "LKE Network Access Control List (IP ACL)"
+	CapabilityLinodes                       string = "Linodes"
+	CapabilityLkeHaControlPlanes            string = "LKE HA Control Planes"
+	CapabilityMachineImages                 string = "Machine Images"
+	CapabilityMetadata                      string = "Metadata"
+	CapabilityNodeBalancers                 string = "NodeBalancers"
+	CapabilityObjectStorage                 string = "Object Storage"
+	CapabilityObjectStorageAccessKeyRegions string = "Object Storage Access Key Regions"
+	CapabilityObjectStorageEndpointTypes    string = "Object Storage Endpoint Types"
+	CapabilityPlacementGroup                string = "Placement Group"
+	CapabilityPremiumPlans                  string = "Premium Plans"
+	CapabilityQuadraT1UVPU                  string = "NETINT Quadra T1U"
+	CapabilitySupportTicketSeverity         string = "Support Ticket Severity"
+	CapabilityVPCs                          string = "VPCs"
+	CapabilityVPCsExtra                     string = "VPCs Extra"
+	CapabilityVlans                         string = "Vlans"
+
+	// Deprecated: CapabilityObjectStorageRegions constant has been
+	// renamed to `CapabilityObjectStorageAccessKeyRegions`.
+	CapabilityObjectStorageRegions string = CapabilityObjectStorageAccessKeyRegions
 )
 
 // Region-related endpoints have a custom expiry time as the
