@@ -869,6 +869,24 @@ func TestInstance_withBlockStorageEncryption(t *testing.T) {
 	require.True(t, slices.Contains(inst.Capabilities, "Block Storage Encryption"))
 }
 
+func TestInstance_withVPU(t *testing.T) {
+	client, clientTeardown := createTestClient(t, "fixtures/TestInstance_withVPU")
+
+	inst, err := createInstance(t, client, true, func(client *linodego.Client, options *linodego.InstanceCreateOptions) {
+		options.Region = "us-lax"
+		options.Type = "g1-accelerated-netint-vpu-t1u1-s"
+		options.Label = "go-inst-test-create-vpu"
+	})
+	require.NoError(t, err)
+
+	defer func() {
+		client.DeleteInstance(context.Background(), inst.ID)
+		clientTeardown()
+	}()
+
+	require.NotNil(t, inst.Specs.AcceleratedDevices)
+}
+
 func TestInstance_withPG(t *testing.T) {
 	client, clientTeardown := createTestClient(t, "fixtures/TestInstance_withPG")
 
